Module node

Module node 

Base node types and identifiers for the B-tree.

Node is an abstract base class. In Rust, we use an enum for the closed set of node types, plus utilities for node ID generation.

Enums

NodeType
Identifies the kind of a tree node.

Constants

NULL_NODE_ID
Sentinel value representing a null/uninitialized node ID.